==> guard-1.3.8-sources.jar: cn/authing/guard/RegisterContainer.java <==
package cn.authing.guard;

import android.content.Context;
import android.content.res.TypedArray;
import android.util.AttributeSet;
import android.widget.LinearLayout;

import androidx.annotation.Nullable;

import cn.authing.guard.analyze.Analyzer;

public class RegisterContainer extends LinearLayout {

    private RegisterType type;

    public RegisterContainer(Context context) {
        this(context, null);
    }

    public RegisterContainer(Context context, @Nullable AttributeSet attrs) {
        this(context, attrs, 0);
    }

    public RegisterContainer(Context context, @Nullable AttributeSet attrs, int defStyleAttr) {
        this(context, attrs, defStyleAttr, 0);
    }

    public enum RegisterType {
        EByPhoneCodePassword,
        EByEmailPassword,
        EByEmailCode,
    }

    public RegisterContainer(Context context, AttributeSet attrs, int defStyleAttr, int defStyleRes) {
        super(context, attrs, defStyleAttr, defStyleRes);

        Analyzer.report("RegisterContainer");

        setOrientation(VERTICAL);
        TypedArray array = context.obtainStyledAttributes(attrs, R.styleable.RegisterContainer);
        int t = array.getInt(R.styleable.RegisterContainer_type,2);
        if (t == 2) {
            type = RegisterType.EByPhoneCodePassword;
        } else if (t == 3) {
            type = RegisterType.EByEmailPassword;
        } else if (t == 4) {
            type = RegisterType.EByEmailCode;
        }
        array.recycle();
    }


    public RegisterType getType() {
        return type;
    }
}

==> guard-1.5.2-sources.jar: cn/authing/guard/RegisterContainer.java <==
package cn.authing.guard;

import android.content.Context;
import android.content.res.TypedArray;
import android.util.AttributeSet;
import android.widget.LinearLayout;

import androidx.annotation.Nullable;

import cn.authing.guard.analyze.Analyzer;

public class RegisterContainer extends LinearLayout {

    private RegisterType type;

    public RegisterContainer(Context context) {
        this(context, null);
    }

    public RegisterContainer(Context context, @Nullable AttributeSet attrs) {
        this(context, attrs, 0);
    }

    public RegisterContainer(Context context, @Nullable AttributeSet attrs, int defStyleAttr) {
        this(context, attrs, defStyleAttr, 0);
    }

    public enum RegisterType {
        EByPhoneCodePassword,
        EByEmailPassword,
        EByEmailCode,
        EByPhonePassword,
        EByExtendFiled,
    }

    public RegisterContainer(Context context, AttributeSet attrs, int defStyleAttr, int defStyleRes) {
        super(context, attrs, defStyleAttr, defStyleRes);

        Analyzer.report("RegisterContainer");

        setOrientation(VERTICAL);
        TypedArray array = context.obtainStyledAttributes(attrs, R.styleable.RegisterContainer);
        int t = array.getInt(R.styleable.RegisterContainer_type,2);
        if (t == 2) {
            type = RegisterType.EByPhoneCodePassword;
        } else if (t == 3) {
            type = RegisterType.EByEmailPassword;
        } else if (t == 4) {
            type = RegisterType.EByEmailCode;
        } else if (t == 5) {
            type = RegisterType.EByPhonePassword;
        } else if (t == 6) {
            type = RegisterType.EByExtendFiled;
        }
        array.recycle();
    }


    public RegisterType getType() {
        return type;
    }
}
